% --------------------------------------------------------------------------
%  periodic solutions of CLARINETTE model by HBM with MANLAB
%  -------------------------------------------------------------------------
%
%   Model equation
%   --------------
%
%  from  "Simulation of single-reed
%  instruments oscillation based on modal decomposition of bore and reed
%  dynamics", International Congress of Acoustics (ICA'07)
%
%  x''+qr*wr x' + wr^2 x = wr^2 p
%  pn'' + 2alphan*c pn' + wn^2 pn = 2c/L u'  pour n de 1 � N (= nb modes)
%  u = zeta (1 -gamma +x) sqrt(gamma - p)
%  p = p1 + .. + pN
%
%  Unknowns x(t) , pn(t) and their derivatives, u(t)  
%  Real parameter : qr, wr, alphan, c, wn, L
%  Bifurcation parameter : gamma
%
%   we set    y = x'
%            zn = pn'
%            v = sqrt(gamma - p)
%  
%   then
%
%    x'  =     y
%    y'  =    wr^2 (p1+..+pN) -qr*wr y -wr^2 x 
%    pn'   =  zn                                 for n=1..N
%    zn'-2c/L u' = -2alphan*c zn -wn^2 pn        for n=1..N
%    0 = -u + zeta (1 - gamma + x) v
%    0 = -v^2 + gamma - p
%
%
%    With  Z(t) = [ x y   p1 ... pn  z1  ... zn u v  ]  (Neq=4) the system becomes
%  
%   -->   m(Z') = lamnda c1 + l0(Z) + lambda l1(Z) + q(Z,Z) 
%
%  
%  Harmonic balance
%  ----------------
%
%
%  Z(t) = Z0 + Z1c cos(omega t) + Z1s sin(omega t) + Z2c cos(2 Omega t) + Z2s sin(2 Omega t) + ... 
%              ...  + ZHc cos(H omega t) + ZHs sin(H omega t).
%
%  the balance of the harmonics leads to a large system of size  Neq*(2H+1)
%
%      C0    +     lambda C1 + L0(U)         + lambda L1(U) + Q(U,U) - omega M(U)= 0 
%                  
%
%     with    U=[Z0  Z1c Z1s  Z2c Z2s  ...  ZHs ]
%  
%
%  Final algebraic system for Manlab  bL0 + bL(bU) + bQ(bU,bU) =0 
%  --------------------------------------------------------------
%
%   bU = [ U , lambda, omega ]
%
%   bL0       = C0
%   bL(bu)    = L0(U) + lambda C1
%   bQ(bU,bU) = Q(U,U) + lambda L1(U) - omega M(U)
%
%
%--------------------------------------------------------------------------

 manlabinit;
 
 H=3;
 N=5;
 Neq=2*N+5;
 
 % the object is created
 ML_problem  = CLARI_NON_B(H,N,Neq); 
 
 % starting point on a brach (previously calculated)
 load('ML_Ustart');
 ML_Ustart = ML_Uj;
 


% definition of a vector whose components are the index of the
% variables to be plotted (x,y) : here the Zc1 and Zs1 against lambda
ML_dispvars = [  (2*H+1)*Neq+1  Neq+1 ; (2*H+1)*Neq+1  2*Neq+1 ];   
% global ML_pointdisplay;
% ML_pointdisplay=1;

 manlabstart; 


