!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!     File 'jacobien.f90'  for MANLAB using HBM              !!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!
!     Two-spring system  : Jacobian matrices J0, JL and JQ
!
!     S. Karkar
!     Oct 2010
!



module jacobien

    use petits_operateurs
    implicit none

    contains
        function J0(lambda,omega)
            real(8), intent(in) :: lambda, omega
            complex(8) J0(nbddl,nbddl)
            J0=0d0
            J0(1,3)=1d0
            J0(2,4)=1d0
            J0(3,:)= [-k1/m,      0d0,  0D0,    0d0]
            J0(4,:)= [0d0,      -k2/m,  0d0,    0D0]
        end function J0

        function JL(lambda,omega,Ustab)
            real(8), intent(in) :: lambda, omega
            complex(8), intent(in) :: Ustab(nbddl)
            complex(8) JL(nbddl,nbddl)
            JL=0D0
            JL(3,1)=-1/m*(3d0*k1*Ustab(1)+k2*Ustab(2))
            JL(3,2)=-1/m*(k1*Ustab(2)+k2*Ustab(1))
            JL(4,1)=-1/m*(k1*Ustab(2)+k2*Ustab(1))
            JL(4,2)=-1/m*(3d0*k2*Ustab(2)+k1*Ustab(1))
 !            JL(3,1:2)=[3D0*k1*Ustab(1)+k2*Ustab(2), k1*Ustab(2)+k2*Ustab(1)]
!            JL(4,1:2)=[k1*Ustab(2)+k2*Ustab(1), 3D0*k2*Ustab(2)+k1*Ustab(1)]
        end function JL

        function JQ(lambda,omega,Ustab,Vstab)
            real(8), intent(in) :: lambda, omega
            complex(8), intent(in) :: Ustab(nbddl), Vstab(nbddl)
            complex(8) JQ(nbddl,nbddl)
            JQ=0d0
            JQ(3,1)= -1/m*((k1+k2)*(3d0/2d0*Ustab(1)*Vstab(1)+0.5d0*Ustab(2)*Vstab(2)))
            JQ(3,2)= -1/m*((k1+k2)*Ustab(1)*Vstab(2))
            JQ(4,1)= -1/m*((k1+k2)*Ustab(1)*Vstab(2))
            JQ(4,2)= -1/m*((k1+k2)*(3d0/2d0*Ustab(2)*Vstab(2)+0.5d0*Ustab(1)*Vstab(1)))
!            JQ(3,1:2) = [(k1+k2)*(3D0/2D0*Ustab(1)*Vstab(1)+0.5D0*Ustab(2)*Vstab(2)), (k1+k2)*Ustab(1)*Vstab(2)]
!            JQ(4,1:2) = [(k1+k2)*Ustab(1)*Vstab(2), (k1+k2)*(3D0/2D0*Ustab(2)*Vstab(2)+0.5D0*Ustab(1)*Vstab(1))]
        end function JQ

end module jacobien
