 %------------------------------------------------------------------
 %    Equilibrage Harmonique     
 %    
 %    La function Q est generique, elle est la meme pour tous
 %    les systemes traites
 
 function [Q] = Q(obj,U,V,H,Neq)
 
  H=obj.H;           % nombre d'harmoniques
  Neq=obj.Neq;       % nombre d'equations
  
  indc=[Neq+1  :2*Neq:Neq*(2*H-1)+1];     % index des petits vecteurs  uic 
  inds=[2*Neq+1:2*Neq:Neq*(2*H)+1  ];     % index des petits vecteurs  uis 

  
  Q=zeros(Neq*(2*H+1),1);
  
  %------------------------------------------------------------------------------ 
  %   ---      equations issues de l'Equilibrage harmonique           ---
  %------------------------------------------------------------------------------

  % traitement des termes quadratiques Q(U,V)   lambda.D(U) et omega M(U)
  %----------------------------------------------------------------------
  
  % Harmonique zéro
   SOM=zeros(Neq,1);
   for j=1:H
      SOM=SOM+pQ(obj,U(indc(j):indc(j)+Neq-1),V(indc(j):indc(j)+Neq-1))  ...
             +pQ(obj,U(inds(j):inds(j)+Neq-1),V(inds(j):inds(j)+Neq-1));
   end
   Q(1:Neq)= 0.5*SOM + pQ(obj,U(1:Neq),V(1:Neq)) ;     ...      %   Q(U,V)
                    
  
  % Harmoniques suivantes 1,2,3, ...
  for ih=1:H   
     SOMC=zeros(Neq,1);
     SOMS=zeros(Neq,1);
     
     % les termes en +
     
        for j=1:ih-1
          SOMC=SOMC+pQ(obj,U(indc(ih-j):indc(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1))  ...
                   -pQ(obj,U(inds(ih-j):inds(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1));
          
          SOMS=SOMS+pQ(obj,U(indc(ih-j):indc(ih-j)+Neq-1),V(inds(j):inds(j)+Neq-1))  ...
                   +pQ(obj,U(inds(ih-j):inds(ih-j)+Neq-1),V(indc(j):indc(j)+Neq-1));
        end
     
     %les termes en -
   
         for j=ih+1:H
            SOMC=SOMC+pQ(obj,U(indc(j):indc(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1))     ...
                     +pQ(obj,U(inds(j):inds(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1))     ...   
                                                                                      ...
                     +pQ(obj,U(indc(j-ih):indc(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1))     ...
                     +pQ(obj,U(inds(j-ih):inds(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1));
                 
            SOMS=SOMS+pQ(obj,U(inds(j):inds(j)+Neq-1),V(indc(j-ih):indc(j-ih)+Neq-1))     ...
                     -pQ(obj,U(indc(j):indc(j)+Neq-1),V(inds(j-ih):inds(j-ih)+Neq-1))     ...   
                                                                                      ...
                     -pQ(obj,U(inds(j-ih):inds(j-ih)+Neq-1),V(indc(j):indc(j)+Neq-1))     ...
                     +pQ(obj,U(indc(j-ih):indc(j-ih)+Neq-1),V(inds(j):inds(j)+Neq-1));                           
                     
         end   
       %les termes courants
         Q(indc(ih):indc(ih)+Neq-1)=0.5*SOMC + pQ(obj,U(indc(ih):indc(ih)+Neq-1),V(1:Neq))   ...      % Q(U,V)
                                             + pQ(obj,U(1:Neq),V(indc(ih):indc(ih)+Neq-1))    ...     %
                                             - ih*V(Neq*(2*H+1)+1)*pM(obj,U(inds(ih):inds(ih)+Neq-1)) ; % - lambda.M(U)
                                             
                                             
         Q(inds(ih):inds(ih)+Neq-1)=0.5*SOMS + pQ(obj,U(inds(ih):inds(ih)+Neq-1),V(1:Neq))   ...      % Q(U,V)
                                             + pQ(obj,U(1:Neq),V(inds(ih):inds(ih)+Neq-1))    ...     %         
                                             + ih*V(Neq*(2*H+1)+1)*pM(obj,U(indc(ih):indc(ih)+Neq-1));  % - lambda.M(U)
   end   
 
  
 
 %------------------------------------------------------------------
 %    
 %    Les functions pQ et pM sont specifiques au pb traite
 %    
 %    ici : l'oscillateur de Duffing
 
 function [pQ] = pQ(obj,U,V)

 
Neq = obj.Neq;                % Nombre d'equations pour chaque harmonique
epsil = obj.epsil;            % epsilon
pQ=zeros(Neq,1);
K=length(obj.XI);
kk=(1:K)';

Q1=U(1:K);
Q2=V(1:K);
V1=U(K+1:2*K);
V2=V(K+1:2*K);
N1=U(2*K+1);
N2=V(2*K+1);


% 2e equation
pQ(K+1:2*K)=-epsil*pi^2*kk.^2.*Q1*N2;

% 3e equation
pQ(2*K+1) = pi^2 * sum(kk.^2.*Q1.*Q2);

  
  function [pM] = pM(obj,U)

 
  Neq = obj.Neq;          % Nombre d'equations pour chaque harmonique
  K=length(obj.XI);
  
  pM=zeros(Neq,1);
  
  pM(1:2*K)=U(1:2*K);
  
