!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!! Equation file for MANLAB / HBM !!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!
!     Prestressed hinged hinged beam
!
!     O. Thomas
!     Oct. 2010
!

module petits_operateurs

  implicit none
  real(8), parameter :: eps=1e-16, pi=3.1415926535897931d0
  integer(4), parameter :: K=3, Neq=2*K+1, nbddl=2*K
  real(8), parameter :: epsil = 6d0
  real(8), parameter, dimension(6) :: OMEG = (/9.8696d0, 39.4784d0, 88.8264d0, 157.9136704d0, 246.74011d0, 355.3057584d0/)
  real(8), parameter, dimension(6) :: XI = (/5d-3, 1.25d-3, 5.55d-4, 3.124d-4, 2d-4, 1.388d-4/)
  real(8), parameter, dimension(6) :: Qext = (/1.15765d0, -9.4918d0, -1.1576d0, 7.614390224d-16, 1.15758729d0, 9.491772753d0/)
  real(8), parameter :: N0=0d0
contains

  function pC0()
    real(8) pC0(Neq)
    ! add here the 'c0' operator
    ! Il faut ajouter les lignes suivantes  L0.F90
    !do i=1,K
    !   L0(Neq+K+i) = Qext(i)
    !end do
    pC0=0d0
    pC0(Neq)=N0
  end function pC0

  function pC1()
    real(8) pC1(Neq)
    ! add here the 'c1' operator
    pC1=0d0
  end function pC1

  function pL0(pu)
    real(8), intent(IN) ::  pu(Neq)
    integer i
    real(8) pL0(Neq), Q(K), V(K)
    real(8) N

    Q=pu(1:K)
    V=pu(K+1:2*K)
    N=pu(2*K+1)
    do i=1,K
       pL0(i)=V(i)
       pl0(K+i)=-2*XI(i)*OMEG(i)*V(i)-(OMEG(i)**2)*Q(i)
    end do
    ! pL0(1:K)= V
    ! pL0(K+1:2*K)= -2*OMEG*XI*V - OMEG**2*Q
    pL0(2*K+1)= N
  end function pL0

  function pL1(pu)
    real(8), intent(IN) ::  pu(Neq)
    real(8) pL1(Neq)
    ! add here the 'l1' operator
    ! as a function of 'pu' vector
    pL1=0d0
  end function pL1

  function pQ(pu,pv)
    real(8), intent(IN) ::  pu(Neq), pv(Neq)
    real(8)  pQ(Neq),Q1(K), Q2(K), V1(K), V2(K)
    real(8)  N1,N2
    integer i

    Q1=pu(1:K)
    V1=pu(K+1:2*K)
    N1=pu(2*K+1)        
    Q2=pv(1:K)
    V2=pv(K+1:2*K)
    N2=pv(2*K+1)        
  
    pQ=0d0
    do i=1,K
       pQ(K+i) = -epsil*(pi**2)*(i**2)*N1*Q2(i)
       pQ(2*K+1) = pQ(2*K+1) - (i**2)*Q1(i)*Q2(i)
    end do
    pQ(2*K+1) = pi**2 * pQ(2*K+1);

  end function pQ

  function pM(pu)
    real(8), intent(IN) :: pu(Neq)
    real(8) pM(Neq)

    pM=0d0
    pM(1:2*K)=pu(1:2*K);
  end function pM

end module petits_operateurs


