%  -----------------------------------
%  Buckling of a DUFFING like equation
%  -----------------------------------
%
%  Duffing equation with a buckling parameter lambda writes:
%
%  (1)   u'' + mu u' + (omeg0^2 - lambda) u + Gamma u^3 =  0
% 
%  with 
%  - u an unknown function of time
%  - lambda a bufurcation parameter (real parameter)
%  - omeg0: the natural frequency (real parameter)
%  - mu: the damping coefficient (real parameter)
%  - Gamma: the non-linearity coefficient
% 
%  We define:
%
%        v = u'
%
%  to obtain the following differential system, 1st order in time:
%
%  52)   u'  =                    +   v
%        v'  =               - ome0^2 u  - mu v  + lambda * u - Gamma * u^3 
%
%  We define:
%
%        w = u^2
%    
%  to have at most quadratic nonlinearities:          
%
%  (3)   u'  =                    +   v
%        v'  =               - ome0^2 u  - mu v  + lambda * u - Gamma * uw 
%        0   =     0              +   w          - u^2
%
%  In statics, u'=v=0 and v'=0 so that:
%
%  (4)   0   =     0         - ome0^2 u  + lambda * u - Gamma * uw 
%        0   =     0              +   w  - u^2
%  
%  is a quadratic algebraic system of the form
%
%        L0(U) + L(U) + Q(U,U) = 0
%
%  with U = [u; w; lambda]
%
%  The Jacobian of the initial dynamical system is:
%
%        JT = [   0                                   1;
%               - ome0^2 + lambda -3 * Gammma * u^2  -mu];
%
%--------------------------------------------------------------------------

 close all
 clear all
 clear classes
 
 addpath('~/MANLAB/SRC')
 
 manlabinit;

 Neq=2;     % Number of equations of (4)
 mu=0;      % Damping coefficient
 ome0 = .5;  % Natural frequency
 Gamma = 1; % N.L. Coefficient
 
 % Object creation 
 ML_problem  = DUFF(Neq,mu,ome0,Gamma);  
 
 % Initial solution vector
 ML_Ustart  = zeros(Neq+1,1);
 ML_Ustart(end)= 0.01;

 % On donne la localisation des variables n�cesaires � la stabilit� 
 % ML_varstab=[Ustab lambda omega H]; -> �quilibrage harmonique 
 % ML_varstab=[Ustab lambda 0]; -> statique (H=0)
 ML_varstab = [1 Neq+1 0];
 
 % definition d'un vecteur contenant les index des variables a afficher 
 % [abscisse1,ordonn�e1;abscisse2,ordonnee2...])
 ML_dispvars = [Neq+1 1];
 
 % ML_stability = 0 -> on ne calcule pas la stabilite;
 % ML_stability = 1 -> on calcule la stabilite;
 ML_stability = 1;
 % ML_algostab = 1 -> algorithme temporel
 % ML_algostab = 2 -> algorithme frequentiel
 ML_algostab = 1;

 ML_pointdisplay = 0;
 ML_globaldisplay = 0;
 
 manlabstart; 


