% plotfloquetmultHBM   Floquet multipliers plot for Manlab/HBM
%    plotfloquetmultHBM(Nds,U,Ustab,fig) plots the 
%    Floquet multiplers:
%    - in the complex plane
%    - as a function of the agular frequency (omega=U(end,:)).
%
%    U is the vector of unknowns of the final algebraic system solved
%    by Manlab and Ustab gathers the stability data. 
%
%    Nds is the initial dynamical system size (this is also the number
%    of Floquet multipliers)
% 
%    fig is a figure handle to plot the graphs
%
%    By O. Thomas / Sept. 2010

function plotfloquetmultHBM(Nds,U,Ustab,fig)

pencolorML;

% Activate axis
% =============

if floor(fig)==fig
  figure(fig)  
else
  disp('fig must be a figure handle')
end
subplot(1,2,2)
hold on
subplot(2,2,1)
hold on
subplot(2,2,3)
hold on

% Plotting the Floquet multipliers
% ================================


omega = U(end,:);
%stab = Ustab(1,:);  
[Bbif,stab]=detectbifurcHBM(Nds,U,Ustab);
Ibif=find((stab(2:end)-stab(1:end-1))~=0);

Ist=find(stab==1);
Iin=find(stab==0);

ALP=Ustab(2:(Nds+1),:);
ALP=sort(ALP,1);
T=2*pi./omega;
TT=ones(Nds,1)*T;
RHO=exp(ALP.*TT);
RHO=sort(RHO,1);

Hand=[];

for ii=1:Nds
  colloc=Col(ii,:);
  subplot(1,2,2)
  plot(real(RHO(ii,Ist)),imag(RHO(ii,Ist)),'o','Color',colloc)
  plot(real(RHO(ii,Iin)),imag(RHO(ii,Iin)),'+','Color',colloc)
  plot(real(RHO(ii,Ibif)),imag(RHO(ii,Ibif)),'s','Color',colloc,'MarkerFaceColor',colloc)

  subplot(2,2,1)
  plot(omega(Ist),abs(RHO(ii,Ist)),'o','Color',colloc)
  plot(omega(Iin),abs(RHO(ii,Iin)),'+','Color',colloc)
  plot(omega(Ibif),abs(RHO(ii,Ibif)),'s','Color',colloc,'MarkerFaceColor',colloc)  
  
  subplot(2,2,3)
  plot(omega(Ist),angle(RHO(ii,Ist))/pi,'o','Color',colloc)
  plot(omega(Iin),angle(RHO(ii,Iin))/pi,'+','Color',colloc)
  plot(omega(Ibif),angle(RHO(ii,Ibif))/pi,'s','Color',colloc,'MarkerFaceColor',colloc)
end
  
subplot(1,2,2)
xlabel('Re(\rho_n)')
ylabel('Im(\rho_n)')
theta=0:pi/100:2*pi;
plot(cos(theta),sin(theta),'k--')
box on

subplot(2,2,1)
xlabel('Angular frequency')
ylabel('|\rho_n|')
plot(get(gca,'Xlim'),[1 1],'k--')
box on

subplot(2,2,3)
xlabel('Angular frequency')
ylabel('arg(\rho_n) [\pi rad]')
plot(get(gca,'Xlim'),[0 0],'k--')
box on